import Qt 4.7

Item {
    id: dialog

    property string title : qsTr("Add Comment")
    property string videoId
    property string service

    signal close

    function setService(name, video) {
        dialog.service = name;
        if (name != "YouTube") {
            dialog.title = qsTr("Share Via ") + name;
            titleInput.text = video.title;
            descriptionEdit.text = video.description;
        }
        dialog.videoId = video.videoId;
    }

    width: parent.width
    anchors { right: parent.left; top: parent.top; bottom: parent.bottom }

    Connections {
        target: dialog.parent

        onDialogClose: {
            dialog.state = "";
            dialog.destroy(600);
        }
    }

    Rectangle {
        id: background

        color: _BACKGROUND_COLOR
        opacity: 0.5
        anchors.fill: dialog
    }

    Text {
        id: titleText

        anchors { horizontalCenter: dialog.horizontalCenter; top: dialog.top; topMargin: 10 }
        text: title
        font.pixelSize: _SMALL_FONT_SIZE
        color: _TEXT_COLOR
    }

    Column {
        id: column

        anchors { fill: dialog; leftMargin: 10; rightMargin: (dialog.width > dialog.height) ? 180 : 10; topMargin: 50; bottomMargin: (dialog.width > dialog.height) ? 10 : 90 }
        spacing: 10

        Text {
            font.pixelSize: _SMALL_FONT_SIZE
            color: "grey"
            text: qsTr("Title")
            visible: dialog.service == "Facebook"
        }

        LineEdit {
            id: titleInput

            width: column.width
            visible: dialog.service == "Facebook"
        }

        Text {
            font.pixelSize: _SMALL_FONT_SIZE
            color: "grey"
            text: qsTr("Description")
            visible: dialog.service == "Facebook"
        }

        Rectangle {
            height: Math.floor(dialog.height / 4)
            width: column.width
            color:  "white"
            border.width: 2
            border.color: descriptionEdit.activeFocus ? _ACTIVE_COLOR_LOW : "grey"
            radius: 5
            visible: dialog.service == "Facebook"

            Flickable {
                anchors { fill: parent; margins: 2 }
                contentWidth: childrenRect.width
                contentHeight: childrenRect.height
                flickableDirection: Flickable.VerticalFlick
                boundsBehavior: Flickable.DragOverBounds
                clip: true

                TextEdit {
                    id: descriptionEdit

                    width: column.width - 4
                    height: Math.floor(dialog.height / 4)
                    font.pixelSize: _STANDARD_FONT_SIZE
                    selectByMouse: true
                    wrapMode: Text.WordWrap
                    selectionColor: _ACTIVE_COLOR_LOW
                }
            }
        }

        Text {
            font.pixelSize: _SMALL_FONT_SIZE
            color: "grey"
            text: qsTr("Message")
            visible: dialog.service == "Facebook"
        }

        Rectangle {
            width: column.width
            height: (dialog.service == "Facebook") ? (Math.floor(dialog.height / 4) + 15) : column.height
            color:  "white"
            border.width: 2
            border.color: commentEdit.activeFocus ? _ACTIVE_COLOR_LOW : "grey"
            radius: 5

            Flickable {
                anchors { fill: parent; margins: 2 }
                contentWidth: childrenRect.width
                contentHeight: childrenRect.height
                flickableDirection: Flickable.VerticalFlick
                boundsBehavior: Flickable.DragOverBounds
                clip: true

                TextEdit {
                    id: commentEdit

                    width: column.width - 4
                    height: parent.parent.height - 4
                    focus: true
                    font.pixelSize: _STANDARD_FONT_SIZE
                    selectByMouse: true
                    wrapMode: Text.WordWrap
                    selectionColor: _ACTIVE_COLOR_LOW
                }
            }
        }
    }

    PushButton {
        id: confirmButton

        width: (dialog.parent.state == "") ? 150 : dialog.width - 20
        anchors { right: dialog.right; bottom: dialog.bottom; margins: 10 }
        icon: (cuteTubeTheme == "light") ? "ui-images/ticklight.png" : "ui-images/tick.png"

        onButtonClicked: {
            if (dialog.service == "Facebook") {
                Sharing.postToFacebook(dialog.videoId, titleInput.text, descriptionEdit.text, commentEdit.text);
            }
            else if (dialog.service == "Twitter") {
            }
            else {
                YouTube.addComment(dialog.videoId, commentEdit.text);
            }
            close();
        }
    }

    CloseButton {
        onButtonClicked: close()
    }

    MouseArea {

        property real xPos

        z: -1
        anchors.fill: dialog
        onPressed: xPos = mouseX
        onReleased: {
            if (xPos - mouseX > 100) {
                close();
            }
        }
    }

    states: State {
        name: "show"
        AnchorChanges { target: dialog; anchors.right: parent.right }
    }

    transitions: Transition {
        AnchorAnimation { easing.type: Easing.OutQuart; duration: 500 }
    }
}
