import Qt 4.7
import QtMultimediaKit 1.2

Rectangle {
    id: window

    property variant currentVideo
    property int playlistPosition : 0

    signal playbackStopped

    function setPlaylist(videoList) {
        currentVideo = videoList[0];
        for (var i = 0; i < videoList.length; i++) {
            playbackModel.append(videoList[i]);
        }
        if (currentVideo.filePath) {
            videoPlayer.setVideo(currentVideo.filePath);
        }
        else {
            YouTube.getVideoUrl(currentVideo.playerUrl);
        }
    }

    function getTime(msecs) {
        /* Convert seconds to HH:MM:SS format */

        var secs = Math.floor(msecs / 1000);
        var hours = Math.floor(secs / 3600);
        var minutes = Math.floor(secs / 60) - (hours * 60);
        var seconds = secs - (hours * 3600) - (minutes * 60);
        if (seconds < 10) {
            seconds = "0" + seconds;
        }
        var duration = minutes + ":" + seconds;
        if (hours > 0) {
            duration = hours + ":" + duration;
        }
        return duration;
    }

    color: "black"

    onPlaylistPositionChanged: {
        var nextVideo = playbackModel.get(playlistPosition);
        if (nextVideo.filePath) {
            videoPlayer.setVideo(nextVideo.filePath);
        }
        else {
            YouTube.getVideoUrl(nextVideo.playerUrl);
        }
        currentVideo = nextVideo;
    }

    Connections {
        target: YouTube
        onGotVideoUrl: videoPlayer.setVideo(videoUrl)
    }

    Video{
        id: videoPlayer

        function setVideo(videoUrl) {
            videoPlayer.source = videoUrl
            videoPlayer.play()
        }

        width: window.width
        height: window.height
        anchors.top: window.top
        z: 30
        onStopped: (playbackModel.count > playlistPosition) ? playlistPosition++ : playbackStopped()

        MouseArea {
            anchors.fill: videoPlayer
            onClicked: controls.showControls = !controls.showControls
        }

        Item {
            id: controls

            property bool showControls : false

            z: 50
            anchors.fill: videoPlayer

            Item {
                id: titleBar

                anchors.top: controls.top
                width: controls.width
                height: 50

                Rectangle {
                    anchors.fill: titleBar
                    width: controls.width
                    height: titleBar.height
                    color: "black"
                    opacity: controls.showControls ? 0.5 : 0
                    smooth: true
                }

                ToolButton {
                    id: minimizeButton

                    anchors { verticalCenter: titleBar.verticalCenter; left: titleBar.left; leftMargin: 10 }
                    icon: "ui-images/minimizeicon.png"
                    opacity: controls.showControls ? 1 : 0

                    Connections {
                        onButtonClicked: Controller.minimize()
                        onButtonHeld: Controller.toggleState()
                    }

                }

                Text {
                    id: title

                    anchors { fill: titleBar; leftMargin: 70; rightMargin: 200 }
                    font.pixelSize: _STANDARD_FONT_SIZE
                    elide: Text.ElideRight
                    verticalAlignment: Text.AlignVCenter
                    color: "white"
                    smooth: true
                    text: currentVideo == undefined ? "" : currentVideo.title
                    opacity: controls.showControls ? 1 : 0
                }

                Text {
                    id: time

                    anchors {right: titleBar.right; rightMargin: 70 }
                    height: titleBar.height
                    font.pixelSize: _STANDARD_FONT_SIZE
                    verticalAlignment: Text.AlignVCenter
                    color: "white"
                    smooth: true
                    text: currentVideo == undefined ? "0:00/0:00" : getTime(videoPlayer.position) + "/" + getTime(videoPlayer.duration)
                    opacity: controls.showControls ? 1 : 0
                }

                CloseButton {
                    id: closeButton

                    anchors { right: titleBar.right; rightMargin: 10; verticalCenter: titleBar.verticalCenter }
                    opacity: controls.showControls ? 1 : 0

                    onButtonClicked: {
                        videoPlayer.stop();
                    }
                }

                Rectangle {
                    id: frame

                    width: 122
                    height: 92
                    anchors { left: titleBar.left; leftMargin: 70; top: titleBar.bottom }
                    color: "black"
                    smooth: true
                    opacity: (controls.showControls && window.state == "") ? 0.5 : 0
                }

                Image {
                    id: thumb

                    anchors { fill: frame; margins: 1 }
                    sourceSize.width: thumb.width
                    sourceSize.height: thumb.height
                    source: !currentVideo ? "" : currentVideo.thumbnail
                    smooth: true
                    opacity: (controls.showControls && window.state == "") ? 1 : 0
                }
            }

            Row {
                id: buttonRow

                anchors { bottom: controls.bottom; bottomMargin: 50; horizontalCenter: controls.horizontalCenter }
                spacing: 50

                PushButton {
                    id: previousButton

                    width: 100
                    height: 100
                    icon: "ui-images/previousicon.png"
                    opacity: controls.showControls ? 1 : 0
                    onButtonClicked: {
                        controlsTimer.restart;
                        if (videoPlayer.position > 5000) {
                            videoPlayer.position = 1;
                        }
                        else if (playlistPosition > 0) {
                            playlistPosition--;
                        }
                    }
                }

                PushButton {
                    id: playButton

                    width: 100
                    height: 100
                    icon: ((videoPlayer.paused) || (videoPlayer.position == videoPlayer.duration) || (videoPlayer.position == 0)) ? "ui-images/playicon.png" : "ui-images/pauseicon.png"
                    opacity: controls.showControls ? 1 : 0
                    onButtonClicked: {
                        controlsTimer.restart;
                        videoPlayer.paused = !videoPlayer.paused;
                    }
                }

                PushButton {
                    id: nextButton

                    width: 100
                    height: 100
                    icon: "ui-images/nexticon.png"
                    opacity: controls.showControls ? 1 : 0
                    onButtonClicked: {
                        controlsTimer.restart;
                        if (playlistPosition < playbackModel.count - 1) {
                            playlistPosition++;
                        }
                    }
                }
            }

            Rectangle {
                width: controls.width
                height: 20
                anchors.bottom: controls.bottom
                color: "black"
                smooth: true
                opacity: controls.showControls ? 0.5 : 0

                Rectangle {
                    id: seekBar

                    width: currentVideo == undefined ? 0 : Math.floor(window.width * (videoPlayer.position / videoPlayer.duration))
                    height: parent.height
                    anchors.bottom: parent.bottom
                    color: _ACTIVE_COLOR_LOW
                    smooth: true
                    opacity: parent.opacity

                    Behavior on width { SmoothedAnimation { velocity: 1200 } }
                }

                MouseArea {
                    id: seekMouseArea

                    width: parent.width
                    height: 50
                    anchors.bottom: parent.bottom
                    onClicked: {
                        controlsTimer.restart;
                        videoPlayer.position = Math.floor((mouseX / window.width) * videoPlayer.duration);
                    }
                }
            }
        }
    }

    Timer {
        id: controlsTimer

        running: controls.showControls
        interval: 3000
        onTriggered: controls.showControls = false
    }

    ListModel {
        id: playbackModel
    }

    ListView {
        id: playlistView

        anchors { fill: window; topMargin: videoPlayer.height + 10 }
        model: playbackModel
        clip: true
        maximumFlickVelocity: 1000
        delegate: PlaybackDelegate {
            id: delegate

            onDelegateClicked: playlistPosition = index;
        }
    }

    states: State {
        name: "portrait"
        when: window.height > window.width
        PropertyChanges { target: videoPlayer; height: 360 }
    }
}
